# DisplayInfo

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**required** | **bool** |  | [optional] 
**read_only** | **bool** |  | [optional] 
**label** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**options** | [**OptionsMetadata**](OptionsMetadata.md) |  | [optional] 
**list_api** | [**ListApiMetadata**](ListApiMetadata.md) |  | [optional] 
**show_copy_to_clipboard** | **bool** |  | [optional] 
**property_applicability** | [**PropertyApplicability**](PropertyApplicability.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


